@@ -55,7 +55,9 @@ async fn main() -> Result<(), Error> {
                 gz.read_to_string(&mut s).unwrap();
                 println!("{}", s);
             }
-            Msg::Close(_) => {}
+            Msg::Close(_) => {
+                println!("Close");
+            }
             Msg::Ping(m) => {
                 println!("ping {:?}", m);
                 socket.send(Msg::Pong(m));
