@@ -102,7 +102,7 @@ impl<R> Reader<R>
                     }
                 }
                 Err(e) => {
-                    error!("{:?}", e);
+                    error!("header_top {:?}", e);
                     self.close_send.send(0).await;
                     break;
                 }
@@ -118,7 +118,7 @@ impl<R> Reader<R>
                         // trace!("header_buf size -> {}", size);
                     }
                     Err(e) => {
-                        error!("{:?}", e);
+                        error!("header_buf {:?}", e);
                         self.close_send.send(0).await;
                         break;
                     }
@@ -135,7 +135,7 @@ impl<R> Reader<R>
                         // trace!("res_masking_key size -> {}", size);
                     }
                     Err(e) => {
-                        error!("{:?}", e);
+                        error!("masking_key {:?}", e);
                         self.close_send.send(0).await;
                         break;
                     }
@@ -161,7 +161,9 @@ impl<R> Reader<R>
                             self.frame.payload.extend_from_slice(&message[0..size]);
                         }
                         Err(e) => {
-                            error!("{:?}", e);
+                            error!("payload {:?}", e);
+                            self.close_send.send(0).await;
+                            break;
                         }
                     }
                 }
